@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "parser.h"
 #include "fake.h"
@@ -47,7 +35,7 @@ ConfigPtr Parser::fromJson(const QByteArray &data)
     }
 
     OutputList outputList;
-    Q_FOREACH (const QVariant &value, outputs) {
+    for (const QVariant &value : outputs) {
         const OutputPtr output = Parser::outputFromJson(value.toMap());
         outputList.insert(output->id(), output);
     }
@@ -116,7 +104,7 @@ OutputPtr Parser::outputFromJson(QMap<QString, QVariant> map)
 
     QStringList preferredModes;
     const QVariantList prefModes = map[QStringLiteral("preferredModes")].toList();
-    Q_FOREACH (const QVariant &mode, prefModes) {
+    for (const QVariant &mode : prefModes) {
         preferredModes.append(mode.toString());
     }
     output->setPreferredModes(preferredModes);
@@ -124,7 +112,7 @@ OutputPtr Parser::outputFromJson(QMap<QString, QVariant> map)
 
     ModeList modelist;
     const QVariantList modes = map[QStringLiteral("modes")].toList();
-    Q_FOREACH (const QVariant &modeValue, modes) {
+    for (const QVariant &modeValue : modes) {
         const ModePtr mode = Parser::modeFromJson(modeValue);
         modelist.insert(mode->id(), mode);
     }
@@ -133,7 +121,7 @@ OutputPtr Parser::outputFromJson(QMap<QString, QVariant> map)
 
     if (map.contains(QStringLiteral("clones"))) {
         QList<int> clones;
-        Q_FOREACH (const QVariant &id, map[QStringLiteral("clones")].toList()) {
+        for (const QVariant &id : map[QStringLiteral("clones")].toList()) {
             clones.append(id.toInt());
         }
 
