@@ -11,7 +11,6 @@
 #include <QObject>
 #include <QRect>
 
-#include <KWayland/Client/dpms.h>
 #include <KWayland/Client/registry.h>
 
 class QThread;
@@ -24,6 +23,9 @@ class ConnectionThread;
 }
 }
 
+class Dpms;
+class DpmsManager;
+
 namespace KScreen
 {
 class DpmsClient : public QObject
@@ -48,13 +50,18 @@ Q_SIGNALS:
     void finished();
 
 private Q_SLOTS:
-    void connected();
     void modeChanged();
 
 private:
-    void changeMode(KWayland::Client::Dpms::Mode mode);
+    enum Mode {
+        On = 0,
+        Standby = 1,
+        Suspend = 2,
+        Off = 3,
+    };
+
+    void changeMode(Mode mode);
     KWayland::Client::ConnectionThread *m_connection = nullptr;
-    KWayland::Client::DpmsManager *m_dpmsManager = nullptr;
     KWayland::Client::Registry *m_registry = nullptr;
     bool m_setOff = true;
     bool m_setOn = false;
@@ -62,6 +69,7 @@ private:
     bool m_supportedOututCount = 0;
     int m_modeChanges = 0;
     QStringList m_excludedOutputNames;
+    DpmsManager *m_manager;
 };
 
 } // namespace
